@@ -1,40 +1,55 @@
-import sys
+import ssl
+import time
 
-sys.path.append("./")
+import requests
+from requests.adapters import HTTPAdapter
+from urllib3.util.ssl_ import create_urllib3_context
 
 from morphapi.utils.data_io import connected_to_internet
 
-import requests
-import time
+mouselight_base_url = "https://ml-neuronbrowser.janelia.org/"
+CIPHERS = ":HIGH:!DH:!aNULL"
 
 
-mouselight_base_url = "http://ml-neuronbrowser.janelia.org/"
+class NoDhAdapter(HTTPAdapter):
+    """A TransportAdapter that disables DH cipher in Requests."""
+
+    def init_poolmanager(self, *args, **kwargs):
+        context = create_urllib3_context(
+            ciphers=CIPHERS, cert_reqs=ssl.CERT_OPTIONAL
+        )
+        kwargs["ssl_context"] = context
+        return super(NoDhAdapter, self).init_poolmanager(*args, **kwargs)
 
 
-def request(url):
+def request(url, verify=True):
     """
     Sends a request to a url
 
-    :param url: 
+    :param url:
 
     """
     if not connected_to_internet():
         raise ConnectionError(
             "You need to have an internet connection to send requests."
         )
-    response = requests.get(url)
+
+    session = requests.Session()
+    session.mount("https://", NoDhAdapter())
+    response = session.get(url, verify=verify)
+
     if response.ok:
         return response
     else:
         exception_string = "URL request failed: {}".format(response.reason)
-    raise ValueError(exception_string + f"url: {url}")
+    raise ValueError(exception_string + f" ; url: {url}")
 
 
 def query_mouselight(query):
     """
     Sends a GET request, not currently used for anything.
 
-    :param query: 
+    :param query:
 
     """
     if not connected_to_internet():
@@ -42,9 +57,7 @@ def query_mouselight(query):
             "You need an internet connection for API queries, sorry."
         )
 
-    base_url = "http://ml-neuronbrowser.janelia.org/"
-
-    full_query = base_url + query
+    full_query = mouselight_base_url + query
 
     # send the query, package the return argument as a json tree
     response = requests.get(full_query)
@@ -65,11 +78,13 @@ def query_mouselight(query):
 
 def post_mouselight(url, query=None, clean=False, attempts=3):
     """
-    sends a POST request to a user URL. Query can be either a string (in which case clean should be False) or a dictionary.
+    sends a POST request to a user URL. Query can be either a string
+    (in which case clean should be False) or a dictionary.
 
-    :param url: 
+    :param url:
     :param query: string or dictionary with query   (Default value = None)
-    :param clean: if not clean, the query is assumed to be in JSON format (Default value = False)
+    :param clean: if not clean, the query is assumed to be in
+    JSON format (Default value = False)
     :param attempts: number of attempts  (Default value = 3)
 
     """
@@ -102,9 +117,8 @@ def post_mouselight(url, query=None, clean=False, attempts=3):
         if request is None:
             raise ConnectionError(
                 "\n\nMouseLight API query failed with error message:\n{}.\
-                        \nPerhaps the server is down, visit 'http://ml-neuronbrowser.janelia.org' to find out.".format(
-                    exception
-                )
+                        \nPerhaps the server is down, visit '{}' "
+                "to find out.".format(exception, mouselight_base_url)
             )
     else:
         raise NotImplementedError
@@ -117,7 +131,8 @@ def post_mouselight(url, query=None, clean=False, attempts=3):
             return jreq
     else:
         raise Exception(
-            "Query failed to run by returning code of {}. {} -- \n\n{}".format(
+            "Query failed to run by returning code "
+            "of {}. {} -- \n\n{}".format(
                 request.status_code, query, request.text
             )
         )
